@@ -92,10 +92,10 @@ class CodeGuruReviewerClient(BaseClient):
     def associate_repository(
         self,
         *,
-        Repository: "RepositoryTypeDef",
+        Repository: RepositoryTypeDef,
         ClientRequestToken: str = ...,
         Tags: Mapping[str, str] = ...,
-        KMSKeyDetails: "KMSKeyDetailsTypeDef" = ...
+        KMSKeyDetails: KMSKeyDetailsTypeDef = ...
     ) -> AssociateRepositoryResponseTypeDef:
         """
         .
@@ -112,12 +112,20 @@ class CodeGuruReviewerClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client/#close)
+        """
+
     def create_code_review(
         self,
         *,
         Name: str,
         RepositoryAssociationArn: str,
-        Type: "CodeReviewTypeTypeDef",
+        Type: CodeReviewTypeTypeDef,
         ClientRequestToken: str = ...
     ) -> CreateCodeReviewResponseTypeDef:
         """
