@@ -6,9 +6,9 @@ Type annotations for codeguru-reviewer service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_codeguru_reviewer.type_defs import AssociateRepositoryRequestRequestTypeDef
+    from mypy_boto3_codeguru_reviewer.type_defs import KMSKeyDetailsTypeDef
 
-    data: AssociateRepositoryRequestRequestTypeDef = {...}
+    data: KMSKeyDetailsTypeDef = {...}
     ```
 """
 import sys
@@ -36,95 +36,82 @@ else:
 
 
 __all__ = (
-    "AssociateRepositoryRequestRequestTypeDef",
-    "AssociateRepositoryResponseTypeDef",
+    "KMSKeyDetailsTypeDef",
+    "ResponseMetadataTypeDef",
     "BranchDiffSourceCodeTypeTypeDef",
     "CodeArtifactsTypeDef",
     "CodeCommitRepositoryTypeDef",
-    "CodeReviewSummaryTypeDef",
-    "CodeReviewTypeDef",
-    "CodeReviewTypeTypeDef",
-    "CommitDiffSourceCodeTypeTypeDef",
-    "CreateCodeReviewRequestRequestTypeDef",
-    "CreateCodeReviewResponseTypeDef",
-    "DescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef",
-    "DescribeCodeReviewRequestRequestTypeDef",
-    "DescribeCodeReviewResponseTypeDef",
-    "DescribeRecommendationFeedbackRequestRequestTypeDef",
-    "DescribeRecommendationFeedbackResponseTypeDef",
-    "DescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef",
-    "DescribeRepositoryAssociationRequestRequestTypeDef",
-    "DescribeRepositoryAssociationResponseTypeDef",
-    "DisassociateRepositoryRequestRequestTypeDef",
-    "DisassociateRepositoryResponseTypeDef",
-    "EventInfoTypeDef",
-    "KMSKeyDetailsTypeDef",
-    "ListCodeReviewsRequestRequestTypeDef",
-    "ListCodeReviewsResponseTypeDef",
-    "ListRecommendationFeedbackRequestRequestTypeDef",
-    "ListRecommendationFeedbackResponseTypeDef",
-    "ListRecommendationsRequestRequestTypeDef",
-    "ListRecommendationsResponseTypeDef",
-    "ListRepositoryAssociationsRequestListRepositoryAssociationsPaginateTypeDef",
-    "ListRepositoryAssociationsRequestRequestTypeDef",
-    "ListRepositoryAssociationsResponseTypeDef",
-    "ListTagsForResourceRequestRequestTypeDef",
-    "ListTagsForResourceResponseTypeDef",
     "MetricsSummaryTypeDef",
     "MetricsTypeDef",
-    "PaginatorConfigTypeDef",
-    "PutRecommendationFeedbackRequestRequestTypeDef",
-    "RecommendationFeedbackSummaryTypeDef",
-    "RecommendationFeedbackTypeDef",
-    "RecommendationSummaryTypeDef",
-    "RepositoryAnalysisTypeDef",
-    "RepositoryAssociationSummaryTypeDef",
-    "RepositoryAssociationTypeDef",
-    "RepositoryHeadSourceCodeTypeTypeDef",
-    "RepositoryTypeDef",
-    "RequestMetadataTypeDef",
-    "ResponseMetadataTypeDef",
-    "RuleMetadataTypeDef",
-    "S3BucketRepositoryTypeDef",
-    "S3RepositoryDetailsTypeDef",
-    "S3RepositoryTypeDef",
-    "SourceCodeTypeTypeDef",
-    "TagResourceRequestRequestTypeDef",
-    "ThirdPartySourceRepositoryTypeDef",
-    "UntagResourceRequestRequestTypeDef",
+    "CommitDiffSourceCodeTypeTypeDef",
     "WaiterConfigTypeDef",
+    "DescribeCodeReviewRequestRequestTypeDef",
+    "DescribeRecommendationFeedbackRequestRequestTypeDef",
+    "RecommendationFeedbackTypeDef",
+    "DescribeRepositoryAssociationRequestRequestTypeDef",
+    "DisassociateRepositoryRequestRequestTypeDef",
+    "EventInfoTypeDef",
+    "ListCodeReviewsRequestRequestTypeDef",
+    "ListRecommendationFeedbackRequestRequestTypeDef",
+    "RecommendationFeedbackSummaryTypeDef",
+    "ListRecommendationsRequestRequestTypeDef",
+    "PaginatorConfigTypeDef",
+    "ListRepositoryAssociationsRequestRequestTypeDef",
+    "RepositoryAssociationSummaryTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "PutRecommendationFeedbackRequestRequestTypeDef",
+    "RuleMetadataTypeDef",
+    "RepositoryHeadSourceCodeTypeTypeDef",
+    "S3RepositoryTypeDef",
+    "ThirdPartySourceRepositoryTypeDef",
+    "TagResourceRequestRequestTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "S3RepositoryDetailsTypeDef",
+    "DescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef",
+    "DescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef",
+    "DescribeRecommendationFeedbackResponseTypeDef",
+    "RequestMetadataTypeDef",
+    "ListRecommendationFeedbackResponseTypeDef",
+    "ListRepositoryAssociationsRequestListRepositoryAssociationsPaginateTypeDef",
+    "ListRepositoryAssociationsResponseTypeDef",
+    "RecommendationSummaryTypeDef",
+    "RepositoryTypeDef",
+    "RepositoryAssociationTypeDef",
+    "S3BucketRepositoryTypeDef",
+    "ListRecommendationsResponseTypeDef",
+    "AssociateRepositoryRequestRequestTypeDef",
+    "AssociateRepositoryResponseTypeDef",
+    "DescribeRepositoryAssociationResponseTypeDef",
+    "DisassociateRepositoryResponseTypeDef",
+    "SourceCodeTypeTypeDef",
+    "CodeReviewSummaryTypeDef",
+    "CodeReviewTypeDef",
+    "RepositoryAnalysisTypeDef",
+    "ListCodeReviewsResponseTypeDef",
+    "CreateCodeReviewResponseTypeDef",
+    "DescribeCodeReviewResponseTypeDef",
+    "CodeReviewTypeTypeDef",
+    "CreateCodeReviewRequestRequestTypeDef",
 )
 
-_RequiredAssociateRepositoryRequestRequestTypeDef = TypedDict(
-    "_RequiredAssociateRepositoryRequestRequestTypeDef",
+KMSKeyDetailsTypeDef = TypedDict(
+    "KMSKeyDetailsTypeDef",
     {
-        "Repository": "RepositoryTypeDef",
-    },
-)
-_OptionalAssociateRepositoryRequestRequestTypeDef = TypedDict(
-    "_OptionalAssociateRepositoryRequestRequestTypeDef",
-    {
-        "ClientRequestToken": str,
-        "Tags": Mapping[str, str],
-        "KMSKeyDetails": "KMSKeyDetailsTypeDef",
+        "KMSKeyId": str,
+        "EncryptionOption": EncryptionOptionType,
     },
     total=False,
 )
 
-
-class AssociateRepositoryRequestRequestTypeDef(
-    _RequiredAssociateRepositoryRequestRequestTypeDef,
-    _OptionalAssociateRepositoryRequestRequestTypeDef,
-):
-    pass
-
-
-AssociateRepositoryResponseTypeDef = TypedDict(
-    "AssociateRepositoryResponseTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "RepositoryAssociation": "RepositoryAssociationTypeDef",
-        "Tags": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
@@ -162,67 +149,26 @@ CodeCommitRepositoryTypeDef = TypedDict(
     },
 )
 
-CodeReviewSummaryTypeDef = TypedDict(
-    "CodeReviewSummaryTypeDef",
+MetricsSummaryTypeDef = TypedDict(
+    "MetricsSummaryTypeDef",
     {
-        "Name": str,
-        "CodeReviewArn": str,
-        "RepositoryName": str,
-        "Owner": str,
-        "ProviderType": ProviderTypeType,
-        "State": JobStateType,
-        "CreatedTimeStamp": datetime,
-        "LastUpdatedTimeStamp": datetime,
-        "Type": TypeType,
-        "PullRequestId": str,
-        "MetricsSummary": "MetricsSummaryTypeDef",
-        "SourceCodeType": "SourceCodeTypeTypeDef",
+        "MeteredLinesOfCodeCount": int,
+        "SuppressedLinesOfCodeCount": int,
+        "FindingsCount": int,
     },
     total=False,
 )
 
-CodeReviewTypeDef = TypedDict(
-    "CodeReviewTypeDef",
+MetricsTypeDef = TypedDict(
+    "MetricsTypeDef",
     {
-        "Name": str,
-        "CodeReviewArn": str,
-        "RepositoryName": str,
-        "Owner": str,
-        "ProviderType": ProviderTypeType,
-        "State": JobStateType,
-        "StateReason": str,
-        "CreatedTimeStamp": datetime,
-        "LastUpdatedTimeStamp": datetime,
-        "Type": TypeType,
-        "PullRequestId": str,
-        "SourceCodeType": "SourceCodeTypeTypeDef",
-        "AssociationArn": str,
-        "Metrics": "MetricsTypeDef",
-        "AnalysisTypes": List[AnalysisTypeType],
-        "ConfigFileState": ConfigFileStateType,
+        "MeteredLinesOfCodeCount": int,
+        "SuppressedLinesOfCodeCount": int,
+        "FindingsCount": int,
     },
     total=False,
 )
 
-_RequiredCodeReviewTypeTypeDef = TypedDict(
-    "_RequiredCodeReviewTypeTypeDef",
-    {
-        "RepositoryAnalysis": "RepositoryAnalysisTypeDef",
-    },
-)
-_OptionalCodeReviewTypeTypeDef = TypedDict(
-    "_OptionalCodeReviewTypeTypeDef",
-    {
-        "AnalysisTypes": Sequence[AnalysisTypeType],
-    },
-    total=False,
-)
-
-
-class CodeReviewTypeTypeDef(_RequiredCodeReviewTypeTypeDef, _OptionalCodeReviewTypeTypeDef):
-    pass
-
-
 CommitDiffSourceCodeTypeTypeDef = TypedDict(
     "CommitDiffSourceCodeTypeTypeDef",
     {
@@ -233,59 +179,15 @@ CommitDiffSourceCodeTypeTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredCreateCodeReviewRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateCodeReviewRequestRequestTypeDef",
+WaiterConfigTypeDef = TypedDict(
+    "WaiterConfigTypeDef",
     {
-        "Name": str,
-        "RepositoryAssociationArn": str,
-        "Type": "CodeReviewTypeTypeDef",
-    },
-)
-_OptionalCreateCodeReviewRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateCodeReviewRequestRequestTypeDef",
-    {
-        "ClientRequestToken": str,
+        "Delay": int,
+        "MaxAttempts": int,
     },
     total=False,
 )
 
-
-class CreateCodeReviewRequestRequestTypeDef(
-    _RequiredCreateCodeReviewRequestRequestTypeDef, _OptionalCreateCodeReviewRequestRequestTypeDef
-):
-    pass
-
-
-CreateCodeReviewResponseTypeDef = TypedDict(
-    "CreateCodeReviewResponseTypeDef",
-    {
-        "CodeReview": "CodeReviewTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredDescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef = TypedDict(
-    "_RequiredDescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef",
-    {
-        "CodeReviewArn": str,
-    },
-)
-_OptionalDescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef = TypedDict(
-    "_OptionalDescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef",
-    {
-        "WaiterConfig": "WaiterConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class DescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef(
-    _RequiredDescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef,
-    _OptionalDescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef,
-):
-    pass
-
-
 DescribeCodeReviewRequestRequestTypeDef = TypedDict(
     "DescribeCodeReviewRequestRequestTypeDef",
     {
@@ -293,14 +195,6 @@ DescribeCodeReviewRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeCodeReviewResponseTypeDef = TypedDict(
-    "DescribeCodeReviewResponseTypeDef",
-    {
-        "CodeReview": "CodeReviewTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredDescribeRecommendationFeedbackRequestRequestTypeDef = TypedDict(
     "_RequiredDescribeRecommendationFeedbackRequestRequestTypeDef",
     {
@@ -324,36 +218,19 @@ class DescribeRecommendationFeedbackRequestRequestTypeDef(
     pass
 
 
-DescribeRecommendationFeedbackResponseTypeDef = TypedDict(
-    "DescribeRecommendationFeedbackResponseTypeDef",
+RecommendationFeedbackTypeDef = TypedDict(
+    "RecommendationFeedbackTypeDef",
     {
-        "RecommendationFeedback": "RecommendationFeedbackTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredDescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef = TypedDict(
-    "_RequiredDescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef",
-    {
-        "AssociationArn": str,
-    },
-)
-_OptionalDescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef = TypedDict(
-    "_OptionalDescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef",
-    {
-        "WaiterConfig": "WaiterConfigTypeDef",
+        "CodeReviewArn": str,
+        "RecommendationId": str,
+        "Reactions": List[ReactionType],
+        "UserId": str,
+        "CreatedTimeStamp": datetime,
+        "LastUpdatedTimeStamp": datetime,
     },
     total=False,
 )
 
-
-class DescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef(
-    _RequiredDescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef,
-    _OptionalDescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef,
-):
-    pass
-
-
 DescribeRepositoryAssociationRequestRequestTypeDef = TypedDict(
     "DescribeRepositoryAssociationRequestRequestTypeDef",
     {
@@ -361,15 +238,6 @@ DescribeRepositoryAssociationRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeRepositoryAssociationResponseTypeDef = TypedDict(
-    "DescribeRepositoryAssociationResponseTypeDef",
-    {
-        "RepositoryAssociation": "RepositoryAssociationTypeDef",
-        "Tags": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 DisassociateRepositoryRequestRequestTypeDef = TypedDict(
     "DisassociateRepositoryRequestRequestTypeDef",
     {
@@ -377,15 +245,6 @@ DisassociateRepositoryRequestRequestTypeDef = TypedDict(
     },
 )
 
-DisassociateRepositoryResponseTypeDef = TypedDict(
-    "DisassociateRepositoryResponseTypeDef",
-    {
-        "RepositoryAssociation": "RepositoryAssociationTypeDef",
-        "Tags": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 EventInfoTypeDef = TypedDict(
     "EventInfoTypeDef",
     {
@@ -395,15 +254,6 @@ EventInfoTypeDef = TypedDict(
     total=False,
 )
 
-KMSKeyDetailsTypeDef = TypedDict(
-    "KMSKeyDetailsTypeDef",
-    {
-        "KMSKeyId": str,
-        "EncryptionOption": EncryptionOptionType,
-    },
-    total=False,
-)
-
 _RequiredListCodeReviewsRequestRequestTypeDef = TypedDict(
     "_RequiredListCodeReviewsRequestRequestTypeDef",
     {
@@ -429,15 +279,6 @@ class ListCodeReviewsRequestRequestTypeDef(
     pass
 
 
-ListCodeReviewsResponseTypeDef = TypedDict(
-    "ListCodeReviewsResponseTypeDef",
-    {
-        "CodeReviewSummaries": List["CodeReviewSummaryTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredListRecommendationFeedbackRequestRequestTypeDef = TypedDict(
     "_RequiredListRecommendationFeedbackRequestRequestTypeDef",
     {
@@ -463,13 +304,14 @@ class ListRecommendationFeedbackRequestRequestTypeDef(
     pass
 
 
-ListRecommendationFeedbackResponseTypeDef = TypedDict(
-    "ListRecommendationFeedbackResponseTypeDef",
+RecommendationFeedbackSummaryTypeDef = TypedDict(
+    "RecommendationFeedbackSummaryTypeDef",
     {
-        "RecommendationFeedbackSummaries": List["RecommendationFeedbackSummaryTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RecommendationId": str,
+        "Reactions": List[ReactionType],
+        "UserId": str,
     },
+    total=False,
 )
 
 _RequiredListRecommendationsRequestRequestTypeDef = TypedDict(
@@ -495,23 +337,12 @@ class ListRecommendationsRequestRequestTypeDef(
     pass
 
 
-ListRecommendationsResponseTypeDef = TypedDict(
-    "ListRecommendationsResponseTypeDef",
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
     {
-        "RecommendationSummaries": List["RecommendationSummaryTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListRepositoryAssociationsRequestListRepositoryAssociationsPaginateTypeDef = TypedDict(
-    "ListRepositoryAssociationsRequestListRepositoryAssociationsPaginateTypeDef",
-    {
-        "ProviderTypes": Sequence[ProviderTypeType],
-        "States": Sequence[RepositoryAssociationStateType],
-        "Names": Sequence[str],
-        "Owners": Sequence[str],
-        "PaginationConfig": "PaginatorConfigTypeDef",
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
     total=False,
 )
@@ -529,116 +360,6 @@ ListRepositoryAssociationsRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListRepositoryAssociationsResponseTypeDef = TypedDict(
-    "ListRepositoryAssociationsResponseTypeDef",
-    {
-        "RepositoryAssociationSummaries": List["RepositoryAssociationSummaryTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListTagsForResourceRequestRequestTypeDef = TypedDict(
-    "ListTagsForResourceRequestRequestTypeDef",
-    {
-        "resourceArn": str,
-    },
-)
-
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
-    {
-        "Tags": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-MetricsSummaryTypeDef = TypedDict(
-    "MetricsSummaryTypeDef",
-    {
-        "MeteredLinesOfCodeCount": int,
-        "SuppressedLinesOfCodeCount": int,
-        "FindingsCount": int,
-    },
-    total=False,
-)
-
-MetricsTypeDef = TypedDict(
-    "MetricsTypeDef",
-    {
-        "MeteredLinesOfCodeCount": int,
-        "SuppressedLinesOfCodeCount": int,
-        "FindingsCount": int,
-    },
-    total=False,
-)
-
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef",
-    {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
-    },
-    total=False,
-)
-
-PutRecommendationFeedbackRequestRequestTypeDef = TypedDict(
-    "PutRecommendationFeedbackRequestRequestTypeDef",
-    {
-        "CodeReviewArn": str,
-        "RecommendationId": str,
-        "Reactions": Sequence[ReactionType],
-    },
-)
-
-RecommendationFeedbackSummaryTypeDef = TypedDict(
-    "RecommendationFeedbackSummaryTypeDef",
-    {
-        "RecommendationId": str,
-        "Reactions": List[ReactionType],
-        "UserId": str,
-    },
-    total=False,
-)
-
-RecommendationFeedbackTypeDef = TypedDict(
-    "RecommendationFeedbackTypeDef",
-    {
-        "CodeReviewArn": str,
-        "RecommendationId": str,
-        "Reactions": List[ReactionType],
-        "UserId": str,
-        "CreatedTimeStamp": datetime,
-        "LastUpdatedTimeStamp": datetime,
-    },
-    total=False,
-)
-
-RecommendationSummaryTypeDef = TypedDict(
-    "RecommendationSummaryTypeDef",
-    {
-        "FilePath": str,
-        "RecommendationId": str,
-        "StartLine": int,
-        "EndLine": int,
-        "Description": str,
-        "RecommendationCategory": RecommendationCategoryType,
-        "RuleMetadata": "RuleMetadataTypeDef",
-        "Severity": SeverityType,
-    },
-    total=False,
-)
-
-RepositoryAnalysisTypeDef = TypedDict(
-    "RepositoryAnalysisTypeDef",
-    {
-        "RepositoryHead": "RepositoryHeadSourceCodeTypeTypeDef",
-        "SourceCodeType": "SourceCodeTypeTypeDef",
-    },
-    total=False,
-)
-
 RepositoryAssociationSummaryTypeDef = TypedDict(
     "RepositoryAssociationSummaryTypeDef",
     {
@@ -654,62 +375,19 @@ RepositoryAssociationSummaryTypeDef = TypedDict(
     total=False,
 )
 
-RepositoryAssociationTypeDef = TypedDict(
-    "RepositoryAssociationTypeDef",
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
     {
-        "AssociationId": str,
-        "AssociationArn": str,
-        "ConnectionArn": str,
-        "Name": str,
-        "Owner": str,
-        "ProviderType": ProviderTypeType,
-        "State": RepositoryAssociationStateType,
-        "StateReason": str,
-        "LastUpdatedTimeStamp": datetime,
-        "CreatedTimeStamp": datetime,
-        "KMSKeyDetails": "KMSKeyDetailsTypeDef",
-        "S3RepositoryDetails": "S3RepositoryDetailsTypeDef",
-    },
-    total=False,
-)
-
-RepositoryHeadSourceCodeTypeTypeDef = TypedDict(
-    "RepositoryHeadSourceCodeTypeTypeDef",
-    {
-        "BranchName": str,
+        "resourceArn": str,
     },
 )
 
-RepositoryTypeDef = TypedDict(
-    "RepositoryTypeDef",
+PutRecommendationFeedbackRequestRequestTypeDef = TypedDict(
+    "PutRecommendationFeedbackRequestRequestTypeDef",
     {
-        "CodeCommit": "CodeCommitRepositoryTypeDef",
-        "Bitbucket": "ThirdPartySourceRepositoryTypeDef",
-        "GitHubEnterpriseServer": "ThirdPartySourceRepositoryTypeDef",
-        "S3Bucket": "S3RepositoryTypeDef",
-    },
-    total=False,
-)
-
-RequestMetadataTypeDef = TypedDict(
-    "RequestMetadataTypeDef",
-    {
-        "RequestId": str,
-        "Requester": str,
-        "EventInfo": "EventInfoTypeDef",
-        "VendorName": VendorNameType,
-    },
-    total=False,
-)
-
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
+        "CodeReviewArn": str,
+        "RecommendationId": str,
+        "Reactions": Sequence[ReactionType],
     },
 )
 
@@ -725,35 +403,12 @@ RuleMetadataTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredS3BucketRepositoryTypeDef = TypedDict(
-    "_RequiredS3BucketRepositoryTypeDef",
+RepositoryHeadSourceCodeTypeTypeDef = TypedDict(
+    "RepositoryHeadSourceCodeTypeTypeDef",
     {
-        "Name": str,
+        "BranchName": str,
     },
 )
-_OptionalS3BucketRepositoryTypeDef = TypedDict(
-    "_OptionalS3BucketRepositoryTypeDef",
-    {
-        "Details": "S3RepositoryDetailsTypeDef",
-    },
-    total=False,
-)
-
-
-class S3BucketRepositoryTypeDef(
-    _RequiredS3BucketRepositoryTypeDef, _OptionalS3BucketRepositoryTypeDef
-):
-    pass
-
-
-S3RepositoryDetailsTypeDef = TypedDict(
-    "S3RepositoryDetailsTypeDef",
-    {
-        "BucketName": str,
-        "CodeArtifacts": "CodeArtifactsTypeDef",
-    },
-    total=False,
-)
 
 S3RepositoryTypeDef = TypedDict(
     "S3RepositoryTypeDef",
@@ -763,26 +418,6 @@ S3RepositoryTypeDef = TypedDict(
     },
 )
 
-SourceCodeTypeTypeDef = TypedDict(
-    "SourceCodeTypeTypeDef",
-    {
-        "CommitDiff": "CommitDiffSourceCodeTypeTypeDef",
-        "RepositoryHead": "RepositoryHeadSourceCodeTypeTypeDef",
-        "BranchDiff": "BranchDiffSourceCodeTypeTypeDef",
-        "S3BucketRepository": "S3BucketRepositoryTypeDef",
-        "RequestMetadata": "RequestMetadataTypeDef",
-    },
-    total=False,
-)
-
-TagResourceRequestRequestTypeDef = TypedDict(
-    "TagResourceRequestRequestTypeDef",
-    {
-        "resourceArn": str,
-        "Tags": Mapping[str, str],
-    },
-)
-
 ThirdPartySourceRepositoryTypeDef = TypedDict(
     "ThirdPartySourceRepositoryTypeDef",
     {
@@ -792,6 +427,14 @@ ThirdPartySourceRepositoryTypeDef = TypedDict(
     },
 )
 
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "resourceArn": str,
+        "Tags": Mapping[str, str],
+    },
+)
+
 UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
@@ -800,11 +443,367 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-WaiterConfigTypeDef = TypedDict(
-    "WaiterConfigTypeDef",
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
     {
-        "Delay": int,
-        "MaxAttempts": int,
+        "Tags": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+S3RepositoryDetailsTypeDef = TypedDict(
+    "S3RepositoryDetailsTypeDef",
+    {
+        "BucketName": str,
+        "CodeArtifacts": CodeArtifactsTypeDef,
     },
     total=False,
 )
+
+_RequiredDescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef = TypedDict(
+    "_RequiredDescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef",
+    {
+        "CodeReviewArn": str,
+    },
+)
+_OptionalDescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef = TypedDict(
+    "_OptionalDescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef",
+    {
+        "WaiterConfig": WaiterConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class DescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef(
+    _RequiredDescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef,
+    _OptionalDescribeCodeReviewRequestCodeReviewCompletedWaitTypeDef,
+):
+    pass
+
+
+_RequiredDescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef = TypedDict(
+    "_RequiredDescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef",
+    {
+        "AssociationArn": str,
+    },
+)
+_OptionalDescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef = TypedDict(
+    "_OptionalDescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef",
+    {
+        "WaiterConfig": WaiterConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class DescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef(
+    _RequiredDescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef,
+    _OptionalDescribeRepositoryAssociationRequestRepositoryAssociationSucceededWaitTypeDef,
+):
+    pass
+
+
+DescribeRecommendationFeedbackResponseTypeDef = TypedDict(
+    "DescribeRecommendationFeedbackResponseTypeDef",
+    {
+        "RecommendationFeedback": RecommendationFeedbackTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+RequestMetadataTypeDef = TypedDict(
+    "RequestMetadataTypeDef",
+    {
+        "RequestId": str,
+        "Requester": str,
+        "EventInfo": EventInfoTypeDef,
+        "VendorName": VendorNameType,
+    },
+    total=False,
+)
+
+ListRecommendationFeedbackResponseTypeDef = TypedDict(
+    "ListRecommendationFeedbackResponseTypeDef",
+    {
+        "RecommendationFeedbackSummaries": List[RecommendationFeedbackSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListRepositoryAssociationsRequestListRepositoryAssociationsPaginateTypeDef = TypedDict(
+    "ListRepositoryAssociationsRequestListRepositoryAssociationsPaginateTypeDef",
+    {
+        "ProviderTypes": Sequence[ProviderTypeType],
+        "States": Sequence[RepositoryAssociationStateType],
+        "Names": Sequence[str],
+        "Owners": Sequence[str],
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+ListRepositoryAssociationsResponseTypeDef = TypedDict(
+    "ListRepositoryAssociationsResponseTypeDef",
+    {
+        "RepositoryAssociationSummaries": List[RepositoryAssociationSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+RecommendationSummaryTypeDef = TypedDict(
+    "RecommendationSummaryTypeDef",
+    {
+        "FilePath": str,
+        "RecommendationId": str,
+        "StartLine": int,
+        "EndLine": int,
+        "Description": str,
+        "RecommendationCategory": RecommendationCategoryType,
+        "RuleMetadata": RuleMetadataTypeDef,
+        "Severity": SeverityType,
+    },
+    total=False,
+)
+
+RepositoryTypeDef = TypedDict(
+    "RepositoryTypeDef",
+    {
+        "CodeCommit": CodeCommitRepositoryTypeDef,
+        "Bitbucket": ThirdPartySourceRepositoryTypeDef,
+        "GitHubEnterpriseServer": ThirdPartySourceRepositoryTypeDef,
+        "S3Bucket": S3RepositoryTypeDef,
+    },
+    total=False,
+)
+
+RepositoryAssociationTypeDef = TypedDict(
+    "RepositoryAssociationTypeDef",
+    {
+        "AssociationId": str,
+        "AssociationArn": str,
+        "ConnectionArn": str,
+        "Name": str,
+        "Owner": str,
+        "ProviderType": ProviderTypeType,
+        "State": RepositoryAssociationStateType,
+        "StateReason": str,
+        "LastUpdatedTimeStamp": datetime,
+        "CreatedTimeStamp": datetime,
+        "KMSKeyDetails": KMSKeyDetailsTypeDef,
+        "S3RepositoryDetails": S3RepositoryDetailsTypeDef,
+    },
+    total=False,
+)
+
+_RequiredS3BucketRepositoryTypeDef = TypedDict(
+    "_RequiredS3BucketRepositoryTypeDef",
+    {
+        "Name": str,
+    },
+)
+_OptionalS3BucketRepositoryTypeDef = TypedDict(
+    "_OptionalS3BucketRepositoryTypeDef",
+    {
+        "Details": S3RepositoryDetailsTypeDef,
+    },
+    total=False,
+)
+
+
+class S3BucketRepositoryTypeDef(
+    _RequiredS3BucketRepositoryTypeDef, _OptionalS3BucketRepositoryTypeDef
+):
+    pass
+
+
+ListRecommendationsResponseTypeDef = TypedDict(
+    "ListRecommendationsResponseTypeDef",
+    {
+        "RecommendationSummaries": List[RecommendationSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredAssociateRepositoryRequestRequestTypeDef = TypedDict(
+    "_RequiredAssociateRepositoryRequestRequestTypeDef",
+    {
+        "Repository": RepositoryTypeDef,
+    },
+)
+_OptionalAssociateRepositoryRequestRequestTypeDef = TypedDict(
+    "_OptionalAssociateRepositoryRequestRequestTypeDef",
+    {
+        "ClientRequestToken": str,
+        "Tags": Mapping[str, str],
+        "KMSKeyDetails": KMSKeyDetailsTypeDef,
+    },
+    total=False,
+)
+
+
+class AssociateRepositoryRequestRequestTypeDef(
+    _RequiredAssociateRepositoryRequestRequestTypeDef,
+    _OptionalAssociateRepositoryRequestRequestTypeDef,
+):
+    pass
+
+
+AssociateRepositoryResponseTypeDef = TypedDict(
+    "AssociateRepositoryResponseTypeDef",
+    {
+        "RepositoryAssociation": RepositoryAssociationTypeDef,
+        "Tags": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeRepositoryAssociationResponseTypeDef = TypedDict(
+    "DescribeRepositoryAssociationResponseTypeDef",
+    {
+        "RepositoryAssociation": RepositoryAssociationTypeDef,
+        "Tags": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DisassociateRepositoryResponseTypeDef = TypedDict(
+    "DisassociateRepositoryResponseTypeDef",
+    {
+        "RepositoryAssociation": RepositoryAssociationTypeDef,
+        "Tags": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+SourceCodeTypeTypeDef = TypedDict(
+    "SourceCodeTypeTypeDef",
+    {
+        "CommitDiff": CommitDiffSourceCodeTypeTypeDef,
+        "RepositoryHead": RepositoryHeadSourceCodeTypeTypeDef,
+        "BranchDiff": BranchDiffSourceCodeTypeTypeDef,
+        "S3BucketRepository": S3BucketRepositoryTypeDef,
+        "RequestMetadata": RequestMetadataTypeDef,
+    },
+    total=False,
+)
+
+CodeReviewSummaryTypeDef = TypedDict(
+    "CodeReviewSummaryTypeDef",
+    {
+        "Name": str,
+        "CodeReviewArn": str,
+        "RepositoryName": str,
+        "Owner": str,
+        "ProviderType": ProviderTypeType,
+        "State": JobStateType,
+        "CreatedTimeStamp": datetime,
+        "LastUpdatedTimeStamp": datetime,
+        "Type": TypeType,
+        "PullRequestId": str,
+        "MetricsSummary": MetricsSummaryTypeDef,
+        "SourceCodeType": SourceCodeTypeTypeDef,
+    },
+    total=False,
+)
+
+CodeReviewTypeDef = TypedDict(
+    "CodeReviewTypeDef",
+    {
+        "Name": str,
+        "CodeReviewArn": str,
+        "RepositoryName": str,
+        "Owner": str,
+        "ProviderType": ProviderTypeType,
+        "State": JobStateType,
+        "StateReason": str,
+        "CreatedTimeStamp": datetime,
+        "LastUpdatedTimeStamp": datetime,
+        "Type": TypeType,
+        "PullRequestId": str,
+        "SourceCodeType": SourceCodeTypeTypeDef,
+        "AssociationArn": str,
+        "Metrics": MetricsTypeDef,
+        "AnalysisTypes": List[AnalysisTypeType],
+        "ConfigFileState": ConfigFileStateType,
+    },
+    total=False,
+)
+
+RepositoryAnalysisTypeDef = TypedDict(
+    "RepositoryAnalysisTypeDef",
+    {
+        "RepositoryHead": RepositoryHeadSourceCodeTypeTypeDef,
+        "SourceCodeType": SourceCodeTypeTypeDef,
+    },
+    total=False,
+)
+
+ListCodeReviewsResponseTypeDef = TypedDict(
+    "ListCodeReviewsResponseTypeDef",
+    {
+        "CodeReviewSummaries": List[CodeReviewSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateCodeReviewResponseTypeDef = TypedDict(
+    "CreateCodeReviewResponseTypeDef",
+    {
+        "CodeReview": CodeReviewTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeCodeReviewResponseTypeDef = TypedDict(
+    "DescribeCodeReviewResponseTypeDef",
+    {
+        "CodeReview": CodeReviewTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredCodeReviewTypeTypeDef = TypedDict(
+    "_RequiredCodeReviewTypeTypeDef",
+    {
+        "RepositoryAnalysis": RepositoryAnalysisTypeDef,
+    },
+)
+_OptionalCodeReviewTypeTypeDef = TypedDict(
+    "_OptionalCodeReviewTypeTypeDef",
+    {
+        "AnalysisTypes": Sequence[AnalysisTypeType],
+    },
+    total=False,
+)
+
+
+class CodeReviewTypeTypeDef(_RequiredCodeReviewTypeTypeDef, _OptionalCodeReviewTypeTypeDef):
+    pass
+
+
+_RequiredCreateCodeReviewRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateCodeReviewRequestRequestTypeDef",
+    {
+        "Name": str,
+        "RepositoryAssociationArn": str,
+        "Type": CodeReviewTypeTypeDef,
+    },
+)
+_OptionalCreateCodeReviewRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateCodeReviewRequestRequestTypeDef",
+    {
+        "ClientRequestToken": str,
+    },
+    total=False,
+)
+
+
+class CreateCodeReviewRequestRequestTypeDef(
+    _RequiredCreateCodeReviewRequestRequestTypeDef, _OptionalCreateCodeReviewRequestRequestTypeDef
+):
+    pass
